==> jc-1.4.0.tar.gz: java/util/logging/MemoryHandler.h <==
// public class java.util.logging.MemoryHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ddab973c71748871 java_util_logging_Handler
// @dep_class 117766ce3b2fbff9 java_util_logging_MemoryHandler

// header file dependencies
// @dep_header java_util_logging_Handler

#include "java/util/logging/Handler.h"

#ifndef _JC_java_util_logging_MemoryHandler_H_
#define _JC_java_util_logging_MemoryHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_Handler$object;
struct _jc_java_util_logging_Level$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_MemoryHandler$sub_refs	_jc_java_util_logging_MemoryHandler$sub_refs;
typedef struct _jc_java_util_logging_MemoryHandler$sub_nonrefs	_jc_java_util_logging_MemoryHandler$sub_nonrefs;
typedef struct _jc_java_util_logging_MemoryHandler$refs	_jc_java_util_logging_MemoryHandler$refs;
typedef struct _jc_java_util_logging_MemoryHandler$nonrefs	_jc_java_util_logging_MemoryHandler$nonrefs;
typedef struct _jc_java_util_logging_MemoryHandler$object	_jc_java_util_logging_MemoryHandler$object;

typedef struct _jc_java_util_logging_MemoryHandler$fields_struct	_jc_java_util_logging_MemoryHandler$fields_struct;
typedef const struct _jc_java_util_logging_MemoryHandler$vmethods	_jc_java_util_logging_MemoryHandler$vmethods;
typedef const struct _jc_java_util_logging_MemoryHandler$vtable	_jc_java_util_logging_MemoryHandler$vtable;
typedef const struct _jc_java_util_logging_MemoryHandler$vtype	_jc_java_util_logging_MemoryHandler$vtype;

// Class fields structure
struct _jc_java_util_logging_MemoryHandler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24Filter;
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24Handler;
};
extern _jc_java_util_logging_MemoryHandler$fields_struct _jc_java_util_logging_MemoryHandler$class_fields;

// Constructors
extern void _jc_java_util_logging_MemoryHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
extern void _jc_java_util_logging_MemoryHandler$method$_init$6f2385b83bc8c08f(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_Handler$object *, jint, struct _jc_java_util_logging_Level$object *);

// Virtual methods
extern void _jc_java_util_logging_MemoryHandler$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
extern void _jc_java_util_logging_MemoryHandler$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
extern struct _jc_java_util_logging_Level$object *_jc_java_util_logging_MemoryHandler$method$getPushLevel$2f90e782c2f9a824(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
extern void _jc_java_util_logging_MemoryHandler$method$publish$f944ff14284acf4e(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_LogRecord$object *);
extern void _jc_java_util_logging_MemoryHandler$method$push$e8891ab835b0da1a(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
extern void _jc_java_util_logging_MemoryHandler$method$setPushLevel$345c57c882b2027a(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_Level$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$getPushLevel$2f90e782c2f9a824;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$publish$f944ff14284acf4e;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$push$e8891ab835b0da1a;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$setPushLevel$345c57c882b2027a;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_util_logging_MemoryHandler$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_java_util_logging_MemoryHandler$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
	struct _jc_java_util_logging_Level$object	*(*getPushLevel$2f90e782c2f9a824)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
	void	(*publish$f944ff14284acf4e)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_LogRecord$object *);
	void	(*push$e8891ab835b0da1a)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *);
	void	(*setPushLevel$345c57c882b2027a)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_Level$object *);
};

// Vtable
struct _jc_java_util_logging_MemoryHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Handler$vmethods	java_util_logging_Handler;
	_jc_java_util_logging_MemoryHandler$vmethods	java_util_logging_MemoryHandler;
};

// Vtype
struct _jc_java_util_logging_MemoryHandler$vtype {
	_jc_type			type;
	_jc_java_util_logging_MemoryHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_MemoryHandler$sub_refs {
	_jc_object_array	*buffer;
	struct _jc_java_util_logging_Level$object	*pushLevel;
	struct _jc_java_util_logging_Handler$object	*target;
};

// Reference instance fields (object)
struct _jc_java_util_logging_MemoryHandler$refs {
    _jc_java_util_logging_MemoryHandler$sub_refs	java_util_logging_MemoryHandler;
    _jc_java_util_logging_Handler$sub_refs	java_util_logging_Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_MemoryHandler$sub_nonrefs {
	jint	position;
	jint	numPublished;
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_MemoryHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Handler$sub_nonrefs	java_util_logging_Handler;
    _jc_java_util_logging_MemoryHandler$sub_nonrefs	java_util_logging_MemoryHandler;
};

// Object instance structure
struct _jc_java_util_logging_MemoryHandler$object {
	_jc_java_util_logging_MemoryHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_MemoryHandler$vtype	*vtype;
	_jc_java_util_logging_MemoryHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_MemoryHandler$vtype _jc_java_util_logging_MemoryHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_MemoryHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_MemoryHandler$class_object;

#endif	/* _JC_java_util_logging_MemoryHandler_H_ */

==> jc-1.4.6.tar.gz: java/util/logging/MemoryHandler.h <==
// public class java.util.logging.MemoryHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ddab973c71748871 java_util_logging_Handler
// @dep_class 117766ce3b2fbff9 java_util_logging_MemoryHandler

// header file dependencies
// @dep_header java_util_logging_Handler

#include "java/util/logging/Handler.h"

#ifndef _JC_java_util_logging_MemoryHandler_H_
#define _JC_java_util_logging_MemoryHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_Handler$object;
struct _jc_java_util_logging_Level$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_MemoryHandler$sub_refs	_jc_java_util_logging_MemoryHandler$sub_refs;
typedef struct _jc_java_util_logging_MemoryHandler$sub_nonrefs	_jc_java_util_logging_MemoryHandler$sub_nonrefs;
typedef struct _jc_java_util_logging_MemoryHandler$refs	_jc_java_util_logging_MemoryHandler$refs;
typedef struct _jc_java_util_logging_MemoryHandler$nonrefs	_jc_java_util_logging_MemoryHandler$nonrefs;
typedef struct _jc_java_util_logging_MemoryHandler$object	_jc_java_util_logging_MemoryHandler$object;

typedef struct _jc_java_util_logging_MemoryHandler$fields_struct	_jc_java_util_logging_MemoryHandler$fields_struct;
typedef const struct _jc_java_util_logging_MemoryHandler$vmethods	_jc_java_util_logging_MemoryHandler$vmethods;
typedef const struct _jc_java_util_logging_MemoryHandler$vtable	_jc_java_util_logging_MemoryHandler$vtable;
typedef const struct _jc_java_util_logging_MemoryHandler$vtype	_jc_java_util_logging_MemoryHandler$vtype;

// Class fields structure
struct _jc_java_util_logging_MemoryHandler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24Filter;
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24Handler;
};
extern _jc_java_util_logging_MemoryHandler$fields_struct _jc_java_util_logging_MemoryHandler$class_fields;

// Constructors
extern void _jc_java_util_logging_MemoryHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_MemoryHandler$method$_init$6f2385b83bc8c08f(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_Handler$object *, jint, struct _jc_java_util_logging_Level$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_logging_MemoryHandler$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_MemoryHandler$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_logging_Level$object *_jc_java_util_logging_MemoryHandler$method$getPushLevel$2f90e782c2f9a824(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_MemoryHandler$method$publish$f944ff14284acf4e(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_MemoryHandler$method$push$e8891ab835b0da1a(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_MemoryHandler$method$setPushLevel$345c57c882b2027a(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_Level$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$getPushLevel$2f90e782c2f9a824;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$publish$f944ff14284acf4e;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$push$e8891ab835b0da1a;
extern _jc_method _jc_java_util_logging_MemoryHandler$method_info$setPushLevel$345c57c882b2027a;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_util_logging_MemoryHandler$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_logging_MemoryHandler$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_logging_Level$object	*(*getPushLevel$2f90e782c2f9a824)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
	void	(*publish$f944ff14284acf4e)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
	void	(*push$e8891ab835b0da1a)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *) _JC_JCNI_ATTR;
	void	(*setPushLevel$345c57c882b2027a)(_jc_env *, struct _jc_java_util_logging_MemoryHandler$object *, struct _jc_java_util_logging_Level$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_logging_MemoryHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Handler$vmethods	java_util_logging_Handler;
	_jc_java_util_logging_MemoryHandler$vmethods	java_util_logging_MemoryHandler;
};

// Vtype
struct _jc_java_util_logging_MemoryHandler$vtype {
	_jc_type			type;
	_jc_java_util_logging_MemoryHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_MemoryHandler$sub_refs {
	_jc_object_array	*buffer;
	struct _jc_java_util_logging_Level$object	*pushLevel;
	struct _jc_java_util_logging_Handler$object	*target;
};

// Reference instance fields (object)
struct _jc_java_util_logging_MemoryHandler$refs {
    _jc_java_util_logging_MemoryHandler$sub_refs	java_util_logging_MemoryHandler;
    _jc_java_util_logging_Handler$sub_refs	java_util_logging_Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_MemoryHandler$sub_nonrefs {
	jint	position;
	jint	numPublished;
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_MemoryHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Handler$sub_nonrefs	java_util_logging_Handler;
    _jc_java_util_logging_MemoryHandler$sub_nonrefs	java_util_logging_MemoryHandler;
};

// Object instance structure
struct _jc_java_util_logging_MemoryHandler$object {
	_jc_java_util_logging_MemoryHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_MemoryHandler$vtype	*vtype;
	_jc_java_util_logging_MemoryHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_MemoryHandler$vtype _jc_java_util_logging_MemoryHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_MemoryHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_MemoryHandler$class_object;

#endif	/* _JC_java_util_logging_MemoryHandler_H_ */
